Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Character ¶
type Character struct {
FirstName string
LastName string
Gender string
Age int
AgeCategory string
Orientation string
Height int
Weight int
Profession string
Hobby Hobby
PsychologicalTraits []string
Motivation string
HairColor string
HairStyle string
FacialHair string
EyeColor string
FaceShape string
MouthShape string
NoseShape string
Culture culturegen.Culture
}
Character is a character
func GenerateAdultDescendent ¶
GenerateAdultDescendent generates an adult character based on a couple
func GenerateCharacter ¶
func GenerateCharacter() Character
GenerateCharacter generates a random character
func GenerateCharacterOfCulture ¶
func GenerateCharacterOfCulture(culture culturegen.Culture) Character
GenerateCharacterOfCulture generates a random character with a given culture
func GenerateChild ¶
GenerateChild generates a child character for a couple
func GenerateCompatibleMate ¶
GenerateCompatibleMate generates a character appropriate as a mate for another
func (Character) SetCulture ¶
func (character Character) SetCulture(culture culturegen.Culture) Character
SetCulture sets the culture of the character
type Couple ¶
Couple is a pair of partners
func MarryCouple ¶
MarryCouple returns a couple from two characters
Click to show internal directories.
Click to hide internal directories.